@@ -6,11 +6,11 @@ use re 'eval';
 
 use Digest::MD5    qw(md5_hex);
 use Encode         qw();
-use Carp           qw(croak);
+use Carp           qw(carp croak);
 use base           qw(Text::Markdown);
 use HTML::Entities qw(encode_entities);
 
-our $VERSION   = '1.001';
+our $VERSION   = '1.002';
 $VERSION = eval $VERSION;
 our @EXPORT_OK = qw(markdown);
 
@@ -77,14 +77,17 @@ and borrows from php-markdown, which lives at:
 
     http://michelf.com/projects/php-markdown/extra/
 
-This documentation is going to be moved/copied into this module for clearer reading in a future release..
+This documentation is going to be moved/copied into this module for
+clearer reading in a future release..
 
 =head1 OPTIONS
 
-MultiMarkdown supports a number of options to it's processor which control the behaviour of the output document.
+MultiMarkdown supports a number of options to it's processor which
+control the behaviour of the output document.
 
-These options can be supplied to the constructor, on in a hash with the individual calls to the markdown method.
-See the synopsis for examples of both of the above styles.
+These options can be supplied to the constructor, on in a hash with
+the individual calls to the markdown method. See the synopsis for
+examples of both of the above styles.
 
 The options for the processor are:
 
@@ -96,11 +99,13 @@ Controls the metadata options below.
 
 =item strip_metadata
 
-If true, any metadata in the input document is removed from the output document (note - does not take effect in complete document format).
+If true, any metadata in the input document is removed from the output
+document (note - does not take effect in complete document format).
 
 =item empty element suffix
 
-This option can be used to generate normal HTML output. By default, it is ' />', which is xHTML, change to '>' for normal HTML.
+This option can be used to generate normal HTML output. By default, it
+is ' />', which is xHTML, change to '>' for normal HTML.
 
 =item img_ids
 
@@ -112,6 +117,10 @@ Turn off for compatibility with the original markdown.
 Controls if <hX> tags generated have an id attribute. Defaults to true.
 Turn off for compatibility with the original markdown.
 
+=item heading_ids_spaces_to_dash
+
+Controls whether spaces in headings should be rendered as "-" characters in the heading ids (for compatibility with github markdown, and others)
+
 =item bibliography_title
 
 The title of the generated bibliography, defaults to 'Bibliography'.
@@ -138,8 +147,9 @@ If true, this disables the MultiMarkdown definition list handling.
 
 =back
 
-A number of possible items of metadata can also be supplied as options.
-Note that if the use_metadata is true then the metadata in the document will overwrite the settings on command line.
+A number of possible items of metadata can also be supplied as
+options. Note that if the use_metadata is true then the metadata in
+the document will overwrite the settings on command line.
 
 Metadata options supported are:
 
@@ -157,22 +167,27 @@ Metadata options supported are:
 
 =head1 METADATA
 
-MultiMarkdown supports the concept of 'metadata', which allows you to specify a number of formatting options
-within the document itself. Metadata should be placed in the top few lines of a file, on value per line as colon separated key/value pairs.
-The metadata should be separated from the document with a blank line.
+MultiMarkdown supports the concept of 'metadata', which allows you to
+specify a number of formatting options within the document itself.
+Metadata should be placed in the top few lines of a file, on value per
+line as colon separated key/value pairs. The metadata should be
+separated from the document with a blank line.
 
-Most metadata keys are also supported as options to the constructor, or options
-to the markdown method itself. (Note, as metadata, keys contain space, whereas options the keys are underscore separated.)
+Most metadata keys are also supported as options to the constructor,
+or options to the markdown method itself. (Note, as metadata, keys
+contain space, whereas options the keys are underscore separated.)
 
-You can attach arbitrary metadata to a document, which is output in HTML <META> tags if unknown, see t/11document_format.t for more info.
+You can attach arbitrary metadata to a document, which is output in
+HTML <META> tags if unknown, see t/11document_format.t for more info.
 
 A list of 'known' metadata keys, and their effects are listed below:
 
 =over
 
-=item document format
+=item document_format
 
-If set to 'complete', MultiMarkdown will render an entire xHTML page, otherwise it will render a document fragment
+If set to 'complete', MultiMarkdown will render an entire xHTML page,
+otherwise it will render a document fragment
 
 =over
 
@@ -188,11 +203,13 @@ Sets the page title, if in 'complete' document format.
 
 =item use wikilinks
 
-If set to '1' or 'on', causes links that are WikiWords to automatically be processed into links.
+If set to '1' or 'on', causes links that are WikiWords to
+automatically be processed into links.
 
 =item base url
 
-This is the base URL for referencing wiki pages. In this is not supplied, all wiki links are relative.
+This is the base URL for referencing wiki pages. In this is not
+supplied, all wiki links are relative.
 
 =back
 
@@ -204,34 +221,36 @@ A simple constructor, see the SYNTAX and OPTIONS sections for more information.
 
 =cut
 
+my %defaults;
+BEGIN {
+%defaults = (
+	use_metadata               => 1,
+	base_url                   => '',
+	tab_width                  => 4,
+	document_format            => '',
+	empty_element_suffix       => ' />',
+	use_wikilinks              => 0,
+	heading_ids                => 1,
+	img_ids                    => 1,
+	bibliography_title         => 'Bibliography',
+	self_url                   => '',
+	heading_ids_spaces_to_dash => '',
+	);
+
+}
+
 sub new {
-    my ($class, %p) = @_;
+    my ($class, %args) = @_;
 
-    # Default metadata to 1
-    $p{use_metadata} = 1 unless exists $p{use_metadata};
-    # Squash value to [01]
-    $p{use_metadata} = $p{use_metadata} ? 1 : 0;
+	my %p = ( %defaults, %args );
 
-    $p{base_url} ||= ''; # This is the base url to be used for WikiLinks
+	my @binary = qw(use_metadata use_wikilinks);
+	$p{$_} = $p{$_} ? 1 : 0 for @binary;
 
-    $p{tab_width} = 4 unless (defined $p{tab_width} and $p{tab_width} =~ m/^\d+$/);
-
-    $p{document_format} ||= '';
-
-    $p{empty_element_suffix} ||= ' />'; # Change to ">" for HTML output
-
-    #$p{heading_ids} = defined $p{heading_ids} ? $p{heading_ids} : 1;
-
-    # For use with WikiWords and [[Wiki Links]]
-    # NOTE: You can use \WikiWord to prevent a WikiWord from being treated as a link
-    $p{use_wikilinks} = $p{use_wikilinks} ? 1 : 0;
-
-    $p{heading_ids} = defined $p{heading_ids} ? $p{heading_ids} : 1;
-    $p{img_ids}     = defined $p{img_ids}     ? $p{img_ids}     : 1;
-
-    $p{bibliography_title} ||= 'Bibliography'; # FIXME - Test and document, can also be in metadata!
-
-    $p{self_url} ||= ''; # Used in footnotes to prepend anchors
+	unless( $p{tab_width} =~ m/^\d+$/ ) {
+		carp "tab_width did not look like a decimal number, so using the default 4";
+		$p{tab_width} = 4;
+	}
 
     my $self = { params => \%p };
     bless $self, ref($class) || $class;
@@ -417,7 +436,7 @@ sub _DoDefinitionLists {
 	}{
 		my $list = $1;
 		my $result = $1;
-		
+
 		$list =~ s{
 			(?:$definition_block)\n*
 		}{
@@ -835,6 +854,7 @@ sub _PrintFootnotes {
 sub _Header2Label {
     my ($self, $header) = @_;
     my $label = lc $header;
+    $label =~ s/ +/-/g if $self->{heading_ids_spaces_to_dash};
     $label =~ s/[^A-Za-z0-9:_.-]//g;        # Strip illegal characters
     while ($label =~ s/^[^A-Za-z]//g)
         {};     # Strip illegal leading characters
@@ -1316,7 +1336,7 @@ __END__
 
 Open an issue in the GitHub repo:
 
-	https://github.com/briandfoy/text-multimarkdown/actions
+	https://github.com/briandfoy/text-multimarkdown/issues
 
 Please include with your report: (1) the example input; (2) the output
 you expected; (3) the output Markdown actually produced.
